aboutsummaryrefslogtreecommitdiffstats
path: root/src/junit
diff options
context:
space:
mode:
Diffstat (limited to 'src/junit')
-rw-r--r--src/junit/com/jogamp/junit/util/SingletonTestCase.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/junit/com/jogamp/junit/util/SingletonTestCase.java b/src/junit/com/jogamp/junit/util/SingletonTestCase.java
index 69cb31f..16f2ab3 100644
--- a/src/junit/com/jogamp/junit/util/SingletonTestCase.java
+++ b/src/junit/com/jogamp/junit/util/SingletonTestCase.java
@@ -40,8 +40,8 @@ public abstract class SingletonTestCase extends JunitTracer {
public static final String SINGLE_INSTANCE_LOCK_FILE = "SingletonTestCase.lock";
public static final int SINGLE_INSTANCE_LOCK_PORT = 59999;
- public static final long SINGLE_INSTANCE_LOCK_TO = 6*60*1000; // wait up to 6 mins
- public static final long SINGLE_INSTANCE_LOCK_POLL = 1000; // poll every 1s
+ public static final long SINGLE_INSTANCE_LOCK_TO = 12*60*1000; // wait up to 12 mins
+ public static final long SINGLE_INSTANCE_LOCK_POLL = 1000; // poll every 1s
private static volatile SingletonInstance singletonInstance;